==> attal_0.8.orig.tar.gz: attal-0.8/libClient/graphicalLord.h <==
/****************************************************************
**
** Attal : Lords of Doom
**
** graphicalLord.h
** draw a hero on the map
**
** Version : $Id: graphicalLord.h,v 1.1.1.1 2003/06/15 19:02:00 audoux Exp $
**
** Author(s) : Pascal Audoux
**
** Date : 09/08/2000
**
** Licence :    
**	This program is free software; you can redistribute it and/or modify
**   	it under the terms of the GNU General Public License as published by
**     	the Free Software Foundation; either version 2, or (at your option)
**      any later version.
**
**	This program is distributed in the hope that it will be useful,
** 	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
**
****************************************************************/

#ifndef GRAPHICALLORD_H
#define GRAPHICALLORD_H
 
// generic include files
// include files for QT
#include <qcanvas.h>
#include <qcolor.h>
// application specific includes
#include "libClient/cell.h"

/*              ------------------------------
 *                        GraphicalLord
 *              ------------------------------ */

/** build the graphical part of the Lord */
class GraphicalLord : public QCanvasSprite
{
public:
	/** Constructor */
	GraphicalLord( QCanvas * canvas );

	virtual ~GraphicalLord();

	/** Set the Lord on the cell */
	virtual void setPosition( Cell *cell );
	
	/** Move the lord at the given cell */
	virtual void goTo( GenericCell *cell );
	
	/** Advance animation */
	void advance( int stage );
	
	/** Set color to the lord */
	void setColor( QColor color );
	
	/** Return RTTI */
	int rtti() const { return RTTI; };
	
	static const int RTTI;
	
protected:
	QCanvasPixmap* imageAdvanced() const;
	
};

#endif // GRAPHICALLORD_H

==> attal_0.9.2.orig.tar.gz: attal-0.9.2/libClient/graphicalLord.h <==
/****************************************************************
**
** Attal : Lords of Doom
**
** graphicalLord.h
** draw a hero on the map
**
** Version : $Id: graphicalLord.h,v 1.3 2004/09/05 20:41:32 audoux Exp $
**
** Author(s) : Pascal Audoux
**
** Date : 09/08/2000
**
** Licence :    
**	This program is free software; you can redistribute it and/or modify
**   	it under the terms of the GNU General Public License as published by
**     	the Free Software Foundation; either version 2, or (at your option)
**      any later version.
**
**	This program is distributed in the hope that it will be useful,
** 	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
**
****************************************************************/

#ifndef GRAPHICALLORD_H
#define GRAPHICALLORD_H
 
// generic include files
// include files for QT
#include <qcanvas.h>
#include <qcolor.h>
// application specific includes
#include "libClient/cell.h"
#include "libClient/flag.h"

class GenericPlayer;

/*              ------------------------------
 *                        GraphicalLord
 *              ------------------------------ */

/** build the graphical part of the Lord */
class GraphicalLord : public QCanvasSprite
{
public:
	/** Constructor */
	GraphicalLord( QCanvas * canvas );

	virtual ~GraphicalLord();

	/** Set the Lord on the cell */
	virtual void setPosition( Cell *cell );
	
	/** Move the lord at the given cell */
	virtual void goTo( GenericCell *cell );
	
	virtual void setVisible( bool state );
	
	/** Advance animation */
	void advance( int stage );
	
	virtual void setOwner( GenericPlayer * player );
	
	/** Return RTTI */
	int rtti() const { return RTTI; };
	
	static const int RTTI;
	
protected:
	QCanvasPixmap* imageAdvanced() const;
	Flag * _flag;
};

#endif // GRAPHICALLORD_H
